@@ -19,23 +19,18 @@
  ***************************************************************************/
 
 #include "AppPackageKitResource.h"
-#ifdef NEWAPPSTREAM
-#include <AppStreamQt/icon.h>
 #include <AppStreamQt/screenshot.h>
+#include <AppStreamQt/icon.h>
 #include <AppStreamQt/image.h>
-#else
-#include <AppstreamQt/screenshot.h>
-#include <AppstreamQt/image.h>
-#endif
-// #include <AppstreamQt/release.h>
+#include <AppStreamQt/release.h>
 #include <KLocalizedString>
 #include <KToolInvocation>
 #include <QIcon>
 #include <QProcess>
 #include <QDebug>
 
-AppPackageKitResource::AppPackageKitResource(const Appstream::Component& data, PackageKitBackend* parent)
-    : PackageKitResource(data.packageNames().at(0), QString(), parent)
+AppPackageKitResource::AppPackageKitResource(const AppStream::Component& data, const QString &packageName, PackageKitBackend* parent)
+    : PackageKitResource(packageName, QString(), parent)
     , m_appdata(data)
 {
     Q_ASSERT(data.isValid());
@@ -55,11 +50,10 @@ QString AppPackageKitResource::longDescription()
     return PackageKitResource::longDescription();
 }
 
-QVariant AppPackageKitResource::icon() const
+static QIcon componentIcon(const AppStream::Component &comp)
 {
     QIcon ret;
-#ifdef NEWAPPSTREAM
-    const auto icons = m_appdata.icons();
+    const auto icons = comp.icons();
     if (icons.isEmpty()) {
         ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     } else foreach(const AppStream::Icon &icon, icons) {
@@ -81,24 +75,14 @@ QVariant AppPackageKitResource::icon() const
             ret = QIcon::fromTheme(stock.first());
         }
     }
-#else
-    const auto icons = m_appdata.iconUrls();
-    if (icons.isEmpty())
-        return m_appdata.name();
-    else {
-        for (auto it = icons.constBegin(), itEnd = icons.constEnd(); it!=itEnd; ++it) {
-            if (it->isLocalFile())
-                ret.addFile(it->toLocalFile(), it.key());
-        }
-    }
-
-    if (ret.isNull()) {
-        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
-    }
-#endif
     return ret;
 }
 
+QVariant AppPackageKitResource::icon() const
+{
+    return componentIcon(m_appdata);
+}
+
 QString AppPackageKitResource::license()
 {
     const auto license = m_appdata.projectLicense();
@@ -107,13 +91,13 @@ QString AppPackageKitResource::license()
 
 QStringList AppPackageKitResource::mimetypes() const
 {
-    return findProvides(Appstream::Provides::KindMimetype);
+    return m_appdata.provided(AppStream::Provided::KindMimetype).items();
 }
 
 QStringList AppPackageKitResource::categories()
 {
     auto cats = m_appdata.categories();
-    if (m_appdata.kind() != Appstream::Component::KindAddon)
+    if (m_appdata.kind() != AppStream::Component::KindAddon)
         cats.append(QStringLiteral("Application"));
     return cats;
 }
@@ -134,11 +118,7 @@ QString AppPackageKitResource::appstreamId() const
 
 QUrl AppPackageKitResource::homepage()
 {
-#ifdef NEWAPPSTREAM
-    return m_appdata.url(Appstream::Component::UrlKindHomepage);
-#else
-    return m_appdata.urls().value(Appstream::Component::UrlKindHomepage);
-#endif
+    return m_appdata.url(AppStream::Component::UrlKindHomepage);
 }
 
 bool AppPackageKitResource::isTechnical() const
@@ -148,7 +128,7 @@ bool AppPackageKitResource::isTechnical() const
 
 QStringList AppPackageKitResource::executables() const
 {
-    return findProvides(Appstream::Provides::KindBinary);
+    return m_appdata.provided(AppStream::Provided::KindBinary).items();
 }
 
 void AppPackageKitResource::invokeApplication() const
@@ -158,10 +138,10 @@ void AppPackageKitResource::invokeApplication() const
         QProcess::startDetached(exes.first());
 }
 
-static QUrl imageOfKind(const QList<Appstream::Image>& images, Appstream::Image::Kind kind)
+static QUrl imageOfKind(const QList<AppStream::Image>& images, AppStream::Image::Kind kind)
 {
     QUrl ret;
-    Q_FOREACH (const Appstream::Image &i, images) {
+    Q_FOREACH (const AppStream::Image &i, images) {
         if (i.kind() == kind) {
             ret = i.url();
             break;
@@ -170,10 +150,10 @@ static QUrl imageOfKind(const QList<Appstream::Image>& images, Appstream::Image:
     return ret;
 }
 
-static QUrl screenshot(const Appstream::Component& comp, Appstream::Image::Kind kind)
+static QUrl screenshot(const AppStream::Component& comp, AppStream::Image::Kind kind)
 {
     QUrl ret;
-    Q_FOREACH (const Appstream::Screenshot &s, comp.screenshots()) {
+    Q_FOREACH (const AppStream::Screenshot &s, comp.screenshots()) {
         ret = imageOfKind(s.images(), kind);
         if (s.isDefault() && !ret.isEmpty())
             break;
@@ -183,34 +163,21 @@ static QUrl screenshot(const Appstream::Component& comp, Appstream::Image::Kind
 
 QUrl AppPackageKitResource::screenshotUrl()
 {
-#ifdef NEWAPPSTREAM
-    return screenshot(m_appdata, Appstream::Image::KindSource);
-#else
-    return screenshot(m_appdata, Appstream::Image::Plain);
-#endif
+    return screenshot(m_appdata, AppStream::Image::KindSource);
 }
 
 QUrl AppPackageKitResource::thumbnailUrl()
 {
-#ifdef NEWAPPSTREAM
-    return screenshot(m_appdata, Appstream::Image::KindThumbnail);
-#else
-     return screenshot(m_appdata, Appstream::Image::Thumbnail);
-#endif
+    return screenshot(m_appdata, AppStream::Image::KindThumbnail);
 }
 
 void AppPackageKitResource::fetchScreenshots()
 {
     QList<QUrl> thumbnails, screenshots;
 
-    Q_FOREACH (const Appstream::Screenshot &s, m_appdata.screenshots()) {
-#ifdef NEWAPPSTREAM
-        const QUrl thumbnail = imageOfKind(s.images(), Appstream::Image::KindThumbnail);
-        const QUrl plain = imageOfKind(s.images(), Appstream::Image::KindSource);
-#else
-         const QUrl thumbnail = imageOfKind(s.images(), Appstream::Image::Thumbnail);
-         const QUrl plain = imageOfKind(s.images(), Appstream::Image::Plain);
-#endif
+    Q_FOREACH (const AppStream::Screenshot &s, m_appdata.screenshots()) {
+        const QUrl thumbnail = imageOfKind(s.images(), AppStream::Image::KindThumbnail);
+        const QUrl plain = imageOfKind(s.images(), AppStream::Image::KindSource);
         if (plain.isEmpty())
             qWarning() << "invalid screenshot for" << name();
 
@@ -226,19 +193,6 @@ bool AppPackageKitResource::canExecute() const
     return !executables().isEmpty();
 }
 
-QStringList AppPackageKitResource::findProvides(Appstream::Provides::Kind kind) const
-{
-#ifdef NEWAPPSTREAM
-    return m_appdata.provided(kind).items();
-#else
-    QStringList ret;
-    Q_FOREACH (Appstream::Provides p, m_appdata.provides())
-        if (p.kind() == kind)
-            ret += p.value();
-    return ret;
-#endif
-}
-
 QStringList AppPackageKitResource::allPackageNames() const
 {
     return m_appdata.packageNames();
@@ -263,12 +217,10 @@ QStringList AppPackageKitResource::extends() const
 
 void AppPackageKitResource::fetchChangelog()
 {
-    PackageKitResource::fetchChangelog();
-    //TODO: uncomment when the API is publicly released
-//     QString changelog;
-//     for(const auto& rel: m_appdata.releases()) {
-//         changelog += QStringLiteral("<h3>") + rel.version() + QStringLiteral("</h3>");
-//         changelog += QStringLiteral("<p>") + rel.description() + QStringLiteral("</p>");
-//     }
-//     emit changelogFetched(changelog);
+    QString changelog;
+    for(const auto& rel: m_appdata.releases()) {
+        changelog += QStringLiteral("<h3>") + rel.version() + QStringLiteral("</h3>");
+        changelog += QStringLiteral("<p>") + rel.description() + QStringLiteral("</p>");
+    }
+    emit changelogFetched(changelog);
 }
